@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.55';
+our $VERSION = '0.56';
 
 use Code::TidyAll::Config::INI::Reader 0.44;
 use List::Util 1.45 qw( uniqstr );
@@ -151,6 +151,10 @@ sub _new_tidyall_ini {
             select => [$perl_select],
             ignore => [ $self->_default_perl_ignore ],
         },
+        'Test::Vars' => {
+            select => [$perl_select],
+            ignore => [ $self->_default_perl_ignore ],
+        },
     );
 
     return $self->_config_to_ini( \%tidyall );
@@ -162,7 +166,8 @@ sub _munged_tidyall_ini {
     my $tidyall
         = Code::TidyAll::Config::INI::Reader->read_file('tidyall.ini');
 
-    my %has_default_ignore = map { $_ => 1 } qw( PerlTidy PerlCritic );
+    my %has_default_ignore
+        = map { $_ => 1 } qw( PerlTidy PerlCritic Test::Vars );
     for my $section ( grep { $has_default_ignore{$_} } sort keys %{$tidyall} )
     {
         $tidyall->{$section}{ignore} = [
@@ -276,7 +281,7 @@ Dist::Zilla::Plugin::DROLSKY::TidyAll - Creates default tidyall.ini, perltidyrc,
 
 =head1 VERSION
 
-version 0.55
+version 0.56
 
 =for Pod::Coverage .*
 
