@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.55';
+our $VERSION = '0.56';
 
 use Parse::PMFile;
 
@@ -23,7 +23,7 @@ sub provide_version {
     $self->log_fatal("Cannot find $file to get \$VERSION from")
         unless -e $file;
 
-    my ( $info, $e ) = Parse::PMFile->new->parse($file);
+    my ( $info, undef ) = Parse::PMFile->new->parse($file);
     ( my $package = $self->zilla->name ) =~ s/-/::/g;
     unless ( $info->{$package}{version} ) {
         $self->log_fatal(
@@ -51,7 +51,7 @@ Dist::Zilla::Plugin::DROLSKY::VersionProvider - Gets the distribution version fr
 
 =head1 VERSION
 
-version 0.55
+version 0.56
 
 =for Pod::Coverage .*
 
