@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.55';
+our $VERSION = '0.56';
 
 use Dist::Zilla;
 
@@ -478,10 +478,12 @@ sub _explicit_prereq_plugins {
         # Because Code::TidyAll does not depend on them
         [
             'Prereqs' => 'Modules for use with tidyall' => {
-                -phase         => 'develop',
-                -type          => 'requires',
-                'Perl::Critic' => '1.126',
-                'Perl::Tidy'   => '20160302',
+                -phase                              => 'develop',
+                -type                               => 'requires',
+                'Code::TidyAll::Plugin::Test::Vars' => '0.02',
+                'Perl::Critic'                      => '1.126',
+                'Perl::Tidy'                        => '20160302',
+                'Test::Vars'                        => '0.009',
             }
         ],
     );
@@ -709,7 +711,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.55
+version 0.56
 
 =head1 DESCRIPTION
 
